---
comments: true
---

# ArkLauncher

A GUI Launcher with update system, designed for Artistic Network.

* 📦 框架版本: `maliang`
* ✏️ 项目作者: <https://github.com/the-OmegaLabs>
* 🚀 项目存储库: <https://github.com/the-OmegaLabs/ArkLauncher>

![关注](https://img.shields.io/github/watchers/the-OmegaLabs/ArkLauncher?label=Watchers&logo=github&style=flat "关注")
![复刻](https://img.shields.io/github/forks/the-OmegaLabs/ArkLauncher?label=Forks&logo=github&style=flat "复刻")
![星标](https://img.shields.io/github/stars/the-OmegaLabs/ArkLauncher?label=Stars&color=gold&logo=github&style=flat "星标")
![议题](https://img.shields.io/github/issues/the-OmegaLabs/ArkLauncher?label=Issues&logo=github&style=flat "议题")
![拉取请求](https://img.shields.io/github/issues-pr/the-OmegaLabs/ArkLauncher?label=Pull%20Requests&logo=github&style=flat "拉取请求")
![讨论](https://img.shields.io/github/discussions/the-OmegaLabs/ArkLauncher?label=Discussions&logo=github&style=flat "讨论")

![light](https://github.com/the-OmegaLabs/ArkLauncher/blob/main/preview/preview-cn-light.png?raw=true#only-light)
![dark](https://github.com/the-OmegaLabs/ArkLauncher/blob/main/preview/preview-cn-dark.png?raw=true#only-dark)
